-----------------------------------------------------------------
--
--   Beispielskript zum Vortrag "Access und SQL Server-Security"
--	 AEK 21 im Oktober 2018
--
--   Autor: Bernd Jungbluth										
--   Keine Gewhrleistung, keine Haftung
--
-----------------------------------------------------------------


USE master;
GO

-- ###############################
-- Datenbank
-- ###############################

PRINT 'Anlegen der Datenbank';
GO

CREATE DATABASE AEK21_Variante_SPs; 
GO


USE AEK21_Variante_SPs;
GO

PRINT 'Anlegen der Schemata';
GO

-- ###############################
-- Schemata
-- ###############################

CREATE SCHEMA Personal AUTHORIZATION dbo;
GO
CREATE SCHEMA Vertrieb AUTHORIZATION dbo;
GO

PRINT 'Anlegen der Tabellen';
GO

-- ###############################
-- Tabellen
-- ###############################

CREATE TABLE Vertrieb.Kunden
(	
	KundenID		INT				NOT NULL	IDENTITY(1,1),
	Firma			NVARCHAR(255)	NOT NULL,
	Namenszusatz	NVARCHAR(255)	NULL,
	Strasse			NVARCHAR(60)	NOT NULL,
	Ort				NVARCHAR(100)	NOT NULL,
	RegionID		INT				NULL,
	PLZ				NVARCHAR(10)	NOT NULL,
	Staat			NVARCHAR(15)	NULL,
	Telefon			NVARCHAR(25)	NULL,
	Email			NVARCHAR(255)	NULL,
	iTS				TIMESTAMP		NOT NULL,
	CONSTRAINT PK__Vertrieb_Kunden_KundenID PRIMARY KEY CLUSTERED (KundenID ASC)
);
GO

-- Tabellen
CREATE TABLE Vertrieb.Regionen
(	
	RegionID	INT				NOT NULL	IDENTITY(1,1),
	Region		NVARCHAR(50)	NOT NULL,
	iTS			TIMESTAMP		NOT NULL,
	CONSTRAINT PK__Vertrieb_Regionen_RegionenID PRIMARY KEY CLUSTERED (RegionID ASC),
	CONSTRAINT UK__Vertrieb_Regionen_Region UNIQUE (Region ASC));
GO

CREATE TABLE Personal.Stellen
(	
	StellenID			INT				NOT NULL	IDENTITY(1,1) ,
	Stelle				NVARCHAR(50)	NULL,
	Stellenbeschreibung	NVARCHAR(MAX)	NOT NULL,
	ZuBesetzenAb		DATE			NOT NULL,
	iTS					TIMESTAMP	NOT NULL,
	CONSTRAINT PK__Personal_Stellen_Personal_StellenID PRIMARY KEY CLUSTERED (StellenID ASC),
	CONSTRAINT UK__Personal_Stellen_Stelle_ZuBesetzenAb UNIQUE (Stelle ASC, ZuBesetzenAb ASC)
);
GO

CREATE TABLE Personal.Bewerber
(	
	BewerberID		INT				NOT NULL	IDENTITY(1,1) ,
	StellenID		INT				NULL,
	Nachname		NVARCHAR(20)	NOT NULL,
	Vorname			NVARCHAR(10)	NOT NULL,
	Religion		NVARCHAR(50)	NULL,
	Strasse			NVARCHAR(25)	NOT NULL,
	Hausnummer		NVARCHAR(25)	NOT NULL,
	PLZ				NVARCHAR(10)	NOT NULL,
	Ort				NVARCHAR(50)	NOT NULL,
	Geburtsdatum	DATETIME2(0)	NULL,
	Mobil			NVARCHAR(4)		NULL,
	Email			NVARCHAR(255)	NULL,
	Gehaltswunsch	MONEY			NOT NULL,
	Bemerkungen		NVARCHAR(4000)	NULL,
	iTS				TIMESTAMP		NOT NULL,
	CONSTRAINT PK__Personal_Bewerber_BewerberID PRIMARY KEY CLUSTERED (BewerberID ASC),
	CONSTRAINT UK__Personal_Bewerber_StellenID UNIQUE (StellenID ASC, Email ASC)
);
GO

CREATE TABLE Personal.Mitarbeiter
(	
	MitarbeiterID	INT				NOT NULL	IDENTITY(1,1),
	PersonalNr		CHAR(12)		NOT NULL,
	Nachname		NVARCHAR(20)	NOT NULL,
	Vorname			NVARCHAR(10)	NOT NULL,
	Religion		NVARCHAR(50)	NULL,
	crptReligion	VARBINARY(MAX)	NULL,
	Position		NVARCHAR(30)	NULL,
	Anrede			NVARCHAR(25)	NOT NULL,
	Geburtsdatum	DATETIME2(0)	NULL,
	Einstellung		DATETIME2(0)	NOT NULL,
	Durchwahl		NVARCHAR(4)		NULL,
	Mobil			NVARCHAR(4)		NULL,
	Email			NVARCHAR(255)	NULL,
	Bemerkungen		NVARCHAR(4000)	NULL,
	Vorgesetzter	INT				NULL,
	AktuellesGehalt	MONEY			NOT NULL,
	iTS				TIMESTAMP		NOT NULL,
	CONSTRAINT PK__Personal_Mitarbeiter_MitarbeiterID PRIMARY KEY CLUSTERED (MitarbeiterID ASC),
	CONSTRAINT UK__Personal_Mitarbeiter_PersonalNr UNIQUE (PersonalNr ASC)
);
GO

CREATE TABLE Vertrieb.Artikel
(	
	ArtikelID				INT				NOT NULL	IDENTITY(1,1) ,
	Matchcode				NVARCHAR(9)		NOT NULL,
	Artikel					NVARCHAR(50)	NOT NULL,
	Artikelbeschreibung		NVARCHAR(MAX)	NULL,
	ArtikelgruppeID			INT				NOT NULL,
	Verkaufspreis			MONEY			NULL,
	Groesse					NVARCHAR(5)		NULL,
	Farbe					NVARCHAR(10)	NULL,
	Inaktiv					BIT				NOT NULL,
	iTS						TIMESTAMP		NOT NULL,
	CONSTRAINT PK__Vertrieb_Artikel_ArtikelID PRIMARY KEY CLUSTERED (ArtikelID ASC),
	CONSTRAINT UK__Vertrieb_Artikel_Artikel_ArtikelgruppeID UNIQUE (Artikel ASC, ArtikelgruppeID ASC)
);
GO

CREATE TABLE Vertrieb.Artikelgruppen
(	
	ArtikelgruppeID		INT				NOT NULL	IDENTITY(1,1) ,
	Artikelgruppe		NVARCHAR(50)	NOT NULL,
	AgBeschreibung		NVARCHAR(MAX)	NULL,
	iTS					TIMESTAMP		NOT NULL,
	CONSTRAINT PK__Vertrieb_Artikelgruppen_ArtikelgruppeID PRIMARY KEY CLUSTERED (ArtikelgruppeID ASC),
	CONSTRAINT UK__Vertrieb_Artikelgruppen_Artikelgruppe UNIQUE (Artikelgruppe ASC)
);
GO

CREATE TABLE Vertrieb.Auftraege
(	
	AuftragID		INT				NOT NULL	IDENTITY(1,1),
	KundenID		INT				NOT NULL,
	MitarbeiterID	INT				NOT NULL,
	Auftragsdatum	DATETIME2(0)	NOT NULL,
	iTS				TIMESTAMP		NOT NULL,
	CONSTRAINT PK__Vertrieb_Auftraege_AuftragID PRIMARY KEY CLUSTERED (AuftragID ASC),
	CONSTRAINT UK__Vertrieb_Auftraege_KundenID_MitarbeiterID_Auftragsdatum UNIQUE (KundenID ASC, MitarbeiterID ASC, Auftragsdatum ASC)
);
GO

CREATE TABLE Vertrieb.Auftragspositionen
(	
	AuftragspositionID	INT			NOT NULL	IDENTITY(1,1),
	AuftragID			INT			NOT NULL,
	ArtikelID			INT			NOT NULL,
	Position			INT			NOT NULL,
	Einzelpreis			MONEY		NOT NULL,
	Menge				SMALLINT	NOT NULL,
	iTS					TIMESTAMP	NOT NULL,
	CONSTRAINT PK__Vertrieb_Auftragspositionen_AuftragspositionID PRIMARY KEY CLUSTERED (AuftragspositionID ASC),
	CONSTRAINT UK__Vertrieb_Auftragspositionen_AuftragID_ArtikelID_Position UNIQUE (AuftragID ASC, ArtikelID ASC, Position ASC)
);
GO

-- Fremdschlssel Kunden zu Region
ALTER TABLE Vertrieb.Kunden WITH CHECK 
	ADD CONSTRAINT FK__Vertrieb_Kunden__Vertrieb_Regionen_RegionID FOREIGN KEY(RegionID) REFERENCES Vertrieb.Regionen (RegionID);
ALTER TABLE Vertrieb.Kunden CHECK CONSTRAINT FK__Vertrieb_Kunden__Vertrieb_Regionen_RegionID;

-- Fremdschlssel Artikel zu Artikelgruppen
ALTER TABLE Vertrieb.Artikel WITH CHECK 
	ADD CONSTRAINT FK__Vertrieb_Artikel__Vertrieb_Artikelgruppen_ArtikelgruppeID FOREIGN KEY(ArtikelgruppeID) REFERENCES Vertrieb.Artikelgruppen (ArtikelgruppeID);
ALTER TABLE Vertrieb.Artikel CHECK CONSTRAINT FK__Vertrieb_Artikel__Vertrieb_Artikelgruppen_ArtikelgruppeID;

-- Fremdschlssel Auftraege
ALTER TABLE Vertrieb.Auftraege WITH CHECK 
	ADD CONSTRAINT FK__Vertrieb_Auftraege__Vertrieb_Kunden_KundenID FOREIGN KEY(KundenID) REFERENCES Vertrieb.Kunden (KundenID)
ALTER TABLE Vertrieb.Auftraege CHECK CONSTRAINT FK__Vertrieb_Auftraege__Vertrieb_Kunden_KundenID;
ALTER TABLE Vertrieb.Auftraege WITH CHECK 
	ADD CONSTRAINT FK__Vertrieb_Auftraege__Personal_Mitarbeiter_MitarbeiterID FOREIGN KEY(MitarbeiterID) REFERENCES Personal.Mitarbeiter (MitarbeiterID)
ALTER TABLE Vertrieb.Auftraege CHECK CONSTRAINT FK__Vertrieb_Auftraege__Personal_Mitarbeiter_MitarbeiterID;

-- Fremdschlssel Auftragspositionen
ALTER TABLE Vertrieb.Auftragspositionen WITH CHECK 
	ADD CONSTRAINT FK__Vertrieb_Auftragspositionen__Vertrieb_Auftraege_AuftragID FOREIGN KEY(AuftragID) REFERENCES Vertrieb.Auftraege (AuftragID)
ALTER TABLE Vertrieb.Auftragspositionen CHECK CONSTRAINT FK__Vertrieb_Auftragspositionen__Vertrieb_Auftraege_AuftragID;
ALTER TABLE Vertrieb.Auftragspositionen WITH CHECK 
	ADD CONSTRAINT FK__Vertrieb_Auftragspositionen__Vertrieb_Artikel_ArtikelID FOREIGN KEY(ArtikelID) REFERENCES Vertrieb.Artikel (ArtikelID)
ALTER TABLE Vertrieb.Auftragspositionen CHECK CONSTRAINT FK__Vertrieb_Auftragspositionen__Vertrieb_Artikel_ArtikelID;

-- Fremdschlssel Stellen
ALTER TABLE Personal.Bewerber WITH CHECK 
	ADD CONSTRAINT FK__Personal_Bewerber__Personal_Stellen_StellenID FOREIGN KEY(StellenID) REFERENCES Personal.Stellen (StellenID);
ALTER TABLE Personal.Bewerber CHECK CONSTRAINT FK__Personal_Bewerber__Personal_Stellen_StellenID;



PRINT 'Anlegen der Gespeicherten Prozeduren';
GO

-- ###############################
-- Gespeicherte Prozeduren
-- ###############################

CREATE PROC Vertrieb.pSelectAuftraege
AS
SELECT
		AuftragID, KundenID, MitarbeiterID, Auftragsdatum
FROM	
		Vertrieb.Auftraege
ORDER BY
		Auftragsdatum DESC;
GO

CREATE PROC Vertrieb.pSelectKunden
AS
SELECT	
		KundenID, Firma, Namenszusatz, Strasse, Ort, RegionID, PLZ, Staat, Telefon, Email
FROM	
		Vertrieb.Kunden
ORDER BY	
		Firma;
GO

CREATE PROC Vertrieb.pSelectArtikel
AS
SELECT
		ArtikelID, Matchcode, Artikel, Artikelbeschreibung, ArtikelgruppeID, Verkaufspreis, Groesse, Farbe, Inaktiv
FROM	
		Vertrieb.Artikel
ORDER BY
		Artikel;
GO

CREATE PROC Personal.pSelectMitarbeiter
AS
SELECT	
		MitarbeiterID, PersonalNr, Nachname, Vorname, Position, Anrede, Geburtsdatum, 
		Einstellung, Durchwahl, Mobil, Email, Bemerkungen, Vorgesetzter, AktuellesGehalt, 
		Religion
FROM	
		Personal.Mitarbeiter
ORDER BY	
		Nachname;
GO

CREATE PROC Personal.pSelectStellen
AS
SELECT
		StellenID, Stelle, Stellenbeschreibung, ZuBesetzenAb
FROM		
		Personal.Stellen;
GO

CREATE PROC Personal.pSelectBewerber
AS
SELECT
		BewerberID, StellenID, Nachname, Vorname, Strasse, Hausnummer, PLZ, Ort, 
		Geburtsdatum, Mobil, Email, Gehaltswunsch, Religion, Bemerkungen
FROM
		Personal.Bewerber
ORDER BY
		Nachname, Vorname;
GO




-- ###############################
-- Daten
-- ###############################

PRINT 'Anfgen der Daten';
GO

SET NOCOUNT ON;
SET IDENTITY_INSERT Vertrieb.Regionen ON 
INSERT Vertrieb.Regionen (RegionID, Region) VALUES (1, N'Baden-Wrttemberg')
INSERT Vertrieb.Regionen (RegionID, Region) VALUES (2, N'Bayern')
INSERT Vertrieb.Regionen (RegionID, Region) VALUES (3, N'Berlin')
INSERT Vertrieb.Regionen (RegionID, Region) VALUES (4, N'Cunewald')
INSERT Vertrieb.Regionen (RegionID, Region) VALUES (5, N'Hessen')
INSERT Vertrieb.Regionen (RegionID, Region) VALUES (6, N'Niedersachsen')
INSERT Vertrieb.Regionen (RegionID, Region) VALUES (7, N'Nordrhein-Westfalen')
INSERT Vertrieb.Regionen (RegionID, Region) VALUES (8, N'Rheinland-Pfalz')
INSERT Vertrieb.Regionen (RegionID, Region) VALUES (9, N'Sachsen')
SET IDENTITY_INSERT Vertrieb.Regionen OFF
GO

SET IDENTITY_INSERT Vertrieb.Kunden ON 
INSERT Vertrieb.Kunden (KundenID, Firma, Namenszusatz, Strasse, Ort, RegionID, PLZ, Staat, Telefon, Email) VALUES (1, N'Alfreds Sockenladen', N'Inh. Alfred Kiste', N'Mauerweg 8', N'Berlin', 3, N'12209', N'Deutschland', N'030-0074321', N'info@alfreds-sockenladen.de')
INSERT Vertrieb.Kunden (KundenID, Firma, Namenszusatz, Strasse, Ort, RegionID, PLZ, Staat, Telefon, Email) VALUES (2, N'Zur farbigen Socke', N'Socken in allen Farben, Formen und Gren', N'Retterstr. 10', N'Mannheim', 1, N'68306', N'Deutschland', N'0621-08460', N'zur.blauen.socke@blauesocke.de')
INSERT Vertrieb.Kunden (KundenID, Firma, Namenszusatz, Strasse, Ort, RegionID, PLZ, Staat, Telefon, Email) VALUES (3, N'Socks', N'Come in and find Socks', N'Gartenstr. 17', N'Mnchen', 2, N'80805', N'Deutschland', N'089-039123', N'socks@socks.de')
INSERT Vertrieb.Kunden (KundenID, Firma, Namenszusatz, Strasse, Ort, RegionID, PLZ, Staat, Telefon, Email) VALUES (4, N'Franks Sockenladen', N'Der Second-Foot Shop', N'Ideenplatz 9', N'Aachen', 7, N'52066', N'Deutschland', NULL, N'frank.sockenladen@franksockenladen.de')
INSERT Vertrieb.Kunden (KundenID, Firma, Namenszusatz, Strasse, Ort, RegionID, PLZ, Staat, Telefon, Email) VALUES (5, N'Socks To Run', N'Socken fr den Lufer', N'Pianoweg 11', N'Aschaffenburg', 5, N'63701', N'Deutschland', N'9876', N'socks.to.go@socktogo.com')
INSERT Vertrieb.Kunden (KundenID, Firma, Namenszusatz, Strasse, Ort, RegionID, PLZ, Staat, Telefon, Email) VALUES (6, N'Lehmanns Socken', N'Socken fr Manager', N'Hessengasse 435', N'Frankfurt', 5, N'60528', N'Deutschland', N'069-0245984', N'lehmanns.socken@lehmann.de')
INSERT Vertrieb.Kunden (KundenID, Firma, Namenszusatz, Strasse, Ort, RegionID, PLZ, Staat, Telefon, Email) VALUES (7, N'Morgenstern Socken', N'Socken fr Tag und Nacht', N'Kopperweg 11', N'Leipzig', 9, N'04179', N'Deutschland', N'3176', N'morgenstern.socken@morgenstern.de')
INSERT Vertrieb.Kunden (KundenID, Firma, Namenszusatz, Strasse, Ort, RegionID, PLZ, Staat, Telefon, Email) VALUES (8, N'Olivia Modeladen', N'Inh. Frau Pop-Eye', N'Severinstr. 77', N'Kln', 7, N'50739', N'Deutschland', N'0221-0644327', N'ottilies.modeladen@hotmail.de')
INSERT Vertrieb.Kunden (KundenID, Firma, Namenszusatz, Strasse, Ort, RegionID, PLZ, Staat, Telefon, Email) VALUES (9, N'Socken-Stop', NULL, N'Waldweg 11', N'Cunewalde', 4, N'01307', N'Deutschland', N'0372-035188', N'socken.shop@sockenstop.com')
INSERT Vertrieb.Kunden (KundenID, Firma, Namenszusatz, Strasse, Ort, RegionID, PLZ, Staat, Telefon, Email) VALUES (10, N'Toms Socken', NULL, N'Billstrae 88', N'Mnster', 7, N'44087', N'Deutschland', N'0251-031259', N'toms.socken@online.com')
INSERT Vertrieb.Kunden (KundenID, Firma, Namenszusatz, Strasse, Ort, RegionID, PLZ, Staat, Telefon, Email) VALUES (11, N'Wanderparadies', N'Outdoorkleidung und Zubehr', N'ttinger Pfad 8', N'Stuttgart', 1, N'70563', N'Deutschland', N'0711-020361', N'wanderparadies@web.de')
INSERT Vertrieb.Kunden (KundenID, Firma, Namenszusatz, Strasse, Ort, RegionID, PLZ, Staat, Telefon, Email) VALUES (12, N'Modeland Meier', N'Qualittsware fr die Dame und den Herren', N'Kirchhof 8', N'Neunkirchen', 2, N'63930', N'Deutschland', N'9967', N'post@gmx.de')
INSERT Vertrieb.Kunden (KundenID, Firma, Namenszusatz, Strasse, Ort, RegionID, PLZ, Staat, Telefon, Email) VALUES (13, N'Socks & More', N'Come in and find more', N'Gartenstr. 117', N'Simmern', 8, N'55469', N'Deutschland', N'06761 98547112', N'email@socksandmore.de')
INSERT Vertrieb.Kunden (KundenID, Firma, Namenszusatz, Strasse, Ort, RegionID, PLZ, Staat, Telefon, Email) VALUES (14, N'Flos Sockenladen', N'Socken fr das Haustier', N'Wiesenweg 9', N'Mnchen ', 2, N'80808', N'Deutschland', N'978765', N'flos.sockenladen@toffline.com')
SET IDENTITY_INSERT Vertrieb.Kunden OFF
GO

SET IDENTITY_INSERT Personal.Mitarbeiter ON 
INSERT Personal.Mitarbeiter (MitarbeiterID, PersonalNr, Nachname, Vorname, Religion, crptReligion, Position, Anrede, Geburtsdatum, Einstellung, Durchwahl, Mobil, Email, Bemerkungen, Vorgesetzter, AktuellesGehalt) VALUES (1, N'HP1988020800', N'Hesselbach', N'Petra', N'Keltisch', NULL, N'Geschftsfhrerin', N'Frau', CAST(N'1988-02-08T00:00:00.0000000' AS DateTime2), CAST(N'2011-06-01T00:00:00.0000000' AS DateTime2), N'200', NULL, N'petra.hesselbach@coolesocke.com', NULL, NULL, 3000.0000)
INSERT Personal.Mitarbeiter (MitarbeiterID, PersonalNr, Nachname, Vorname, Religion, crptReligion, Position, Anrede, Geburtsdatum, Einstellung, Durchwahl, Mobil, Email, Bemerkungen, Vorgesetzter, AktuellesGehalt) VALUES (2, N'HA1992081900', N'Hoppenstett', N'Andreas', N'Keltisch', NULL, N'Vertriebsleiter', N'Herr', CAST(N'1992-08-19T00:00:00.0000000' AS DateTime2), CAST(N'2000-02-01T00:00:00.0000000' AS DateTime2), N'100', NULL, N'andreas.hoppenstett@coolesocke.com', NULL, 1, 7500.0000)
INSERT Personal.Mitarbeiter (MitarbeiterID, PersonalNr, Nachname, Vorname, Religion, crptReligion, Position, Anrede, Geburtsdatum, Einstellung, Durchwahl, Mobil, Email, Bemerkungen, Vorgesetzter, AktuellesGehalt) VALUES (3, N'BA1993093000', N'Bienlein', N'Anna', N'Keltisch', NULL, N'Vertrieb', N'Frau', CAST(N'1993-09-30T00:00:00.0000000' AS DateTime2), CAST(N'2010-12-01T00:00:00.0000000' AS DateTime2), N'146', NULL, N'anna.bienlein@coolesocke.com', NULL, 2, 2500.0000)
INSERT Personal.Mitarbeiter (MitarbeiterID, PersonalNr, Nachname, Vorname, Religion, crptReligion, Position, Anrede, Geburtsdatum, Einstellung, Durchwahl, Mobil, Email, Bemerkungen, Vorgesetzter, AktuellesGehalt) VALUES (4, N'BR1998011900', N'Brner', N'Roland', N'Keltisch', NULL, N'Vertrieb', N'Herr', CAST(N'1998-01-19T00:00:00.0000000' AS DateTime2), CAST(N'2007-01-01T00:00:00.0000000' AS DateTime2), N'147', NULL, N'roland.boerner@coolesocke.com', NULL, 2, 3333.0000)
INSERT Personal.Mitarbeiter (MitarbeiterID, PersonalNr, Nachname, Vorname, Religion, crptReligion, Position, Anrede, Geburtsdatum, Einstellung, Durchwahl, Mobil, Email, Bemerkungen, Vorgesetzter, AktuellesGehalt) VALUES (5, N'BS1987040300', N'Beimer', N'Susanne', N'Keltisch', NULL, N'Vertrieb', N'Frau', CAST(N'1987-04-03T00:00:00.0000000' AS DateTime2), CAST(N'2001-05-01T00:00:00.0000000' AS DateTime2), N'141', NULL, N'susanne.beimer@coolesocke.com', NULL, 2, 5000.0000)
INSERT Personal.Mitarbeiter (MitarbeiterID, PersonalNr, Nachname, Vorname, Religion, crptReligion, Position, Anrede, Geburtsdatum, Einstellung, Durchwahl, Mobil, Email, Bemerkungen, Vorgesetzter, AktuellesGehalt) VALUES (6, N'LM1986020700', N'Ldenscheid', N'Melanie', N'Keltisch', NULL, N'Einkaufsleiter', N'Frau', CAST(N'1986-02-07T00:00:00.0000000' AS DateTime2), CAST(N'2003-04-01T00:00:00.0000000' AS DateTime2), N'142', NULL, N'melanie.luedenscheid@coolesocke.com', NULL, 1, 3100.0000)
INSERT Personal.Mitarbeiter (MitarbeiterID, PersonalNr, Nachname, Vorname, Religion, crptReligion, Position, Anrede, Geburtsdatum, Einstellung, Durchwahl, Mobil, Email, Bemerkungen, Vorgesetzter, AktuellesGehalt) VALUES (7, N'BH1996092900', N'Becker', N'Holger', N'Keltisch', NULL, N'Einkauf', N'Herr', CAST(N'1996-09-29T00:00:00.0000000' AS DateTime2), CAST(N'2001-01-02T00:00:00.0000000' AS DateTime2), N'143', NULL, N'holger.becker@coolesocke.com', NULL, 6, 3300.0000)
INSERT Personal.Mitarbeiter (MitarbeiterID, PersonalNr, Nachname, Vorname, Religion, crptReligion, Position, Anrede, Geburtsdatum, Einstellung, Durchwahl, Mobil, Email, Bemerkungen, Vorgesetzter, AktuellesGehalt) VALUES (8, N'BM1998090100', N'Blmel', N'Marina', N'Keltisch', NULL, N'Einkauf', N'Frau', CAST(N'1998-09-01T00:00:00.0000000' AS DateTime2), CAST(N'2005-09-01T00:00:00.0000000' AS DateTime2), N'144', NULL, N'marina.bluemel@coolesocke.com', NULL, 6, 3300.0000)
INSERT Personal.Mitarbeiter (MitarbeiterID, PersonalNr, Nachname, Vorname, Religion, crptReligion, Position, Anrede, Geburtsdatum, Einstellung, Durchwahl, Mobil, Email, Bemerkungen, Vorgesetzter, AktuellesGehalt) VALUES (9, N'SE1995042200', N'Schulz', N'Ellen', N'Keltisch', NULL, N'Einkauf', N'Frau', CAST(N'1995-04-22T00:00:00.0000000' AS DateTime2), CAST(N'2002-11-01T00:00:00.0000000' AS DateTime2), N'145', NULL, N'ellen.schulz@coolesocke.com', NULL, 6, 3000.0000)
INSERT Personal.Mitarbeiter (MitarbeiterID, PersonalNr, Nachname, Vorname, Religion, crptReligion, Position, Anrede, Geburtsdatum, Einstellung, Durchwahl, Mobil, Email, Bemerkungen, Vorgesetzter, AktuellesGehalt) VALUES (10, N'SK1989120100', N'Stromberg', N'Katrin', N'Keltisch', NULL, N'Personal', N'Frau', CAST(N'1989-12-01T00:00:00.0000000' AS DateTime2), CAST(N'2005-10-01T00:00:00.0000000' AS DateTime2), N'149', NULL, N'katrin.stromberg@coolesocke.com', NULL, 1, 3200.0000)
SET IDENTITY_INSERT Personal.Mitarbeiter OFF
GO

SET IDENTITY_INSERT Personal.Stellen ON 
INSERT Personal.Stellen (StellenID, Stelle, Stellenbeschreibung, ZuBesetzenAb) VALUES (1, N'Datenschutzbeauftragter', N'Qualitfiziert nach DSGVO und BDSG', N'20180525')
SET IDENTITY_INSERT Personal.Stellen OFF
GO

SET IDENTITY_INSERT Personal.Bewerber ON 
INSERT Personal.Bewerber (BewerberID, StellenID, Nachname, Vorname, Religion, Strasse, Hausnummer, PLZ, Ort, Geburtsdatum, Mobil, Email, Gehaltswunsch, Bemerkungen) VALUES (1, N'1', N'Mller-Ldenscheid', N'Karl-Heinz', N'keltisch', N'Bulwstr.', N'5', N'60528', N'Frankfurt', CAST(N'2011-11-11T00:00:00.0000000' AS DateTime2), NULL, N'kh@mueller-luedenscheid.de', 4000.0000, NULL)
INSERT Personal.Bewerber (BewerberID, StellenID, Nachname, Vorname, Religion, Strasse, Hausnummer, PLZ, Ort, Geburtsdatum, Mobil, Email, Gehaltswunsch, Bemerkungen) VALUES (2, N'1', N'Meier', N'Brigitte', N'keltisch', N'Kantenstr.', N'77', N'55469', N'Keidelheim', CAST(N'2018-01-10T00:00:00.0000000' AS DateTime2), NULL, N'maria@hoppenstett.de', 4000.0000, NULL)
SET IDENTITY_INSERT Personal.Bewerber OFF
GO

SET IDENTITY_INSERT Vertrieb.Artikelgruppen ON 
INSERT Vertrieb.Artikelgruppen (ArtikelgruppeID, Artikelgruppe, AgBeschreibung) VALUES (1, N'Damensocke "Klassik"', N'klassische Damensocke; 100% Baumwolle, glatt')
INSERT Vertrieb.Artikelgruppen (ArtikelgruppeID, Artikelgruppe, AgBeschreibung) VALUES (2, N'Herrensocke "Klassik"', N'klassische Herrensocke; 100% Baumwolle, glatt')
INSERT Vertrieb.Artikelgruppen (ArtikelgruppeID, Artikelgruppe, AgBeschreibung) VALUES (3, N'Sportsocke "Run"', N'klassische Sportsocke; 100% Baumwolle')
SET IDENTITY_INSERT Vertrieb.Artikelgruppen OFF
GO

SET IDENTITY_INSERT Vertrieb.Artikel ON 
INSERT Vertrieb.Artikel (ArtikelID, Matchcode, Artikel, Artikelbeschreibung, ArtikelgruppeID, Verkaufspreis, Groesse, Farbe, Inaktiv) VALUES (1, N'D01BL3538', N'Damensocke "Klassik" - 35-38 - blau', N'klassische Damensocke aus 100% Baumwolle, glatt, in der Farbe blau', 1, 0.7700, N'35-38', N'blau', 1)
INSERT Vertrieb.Artikel (ArtikelID, Matchcode, Artikel, Artikelbeschreibung, ArtikelgruppeID, Verkaufspreis, Groesse, Farbe, Inaktiv) VALUES (2, N'D01BR3538', N'Damensocke "Klassik" - 35-38 - braun', N'klassische Damensocke aus 100% Baumwolle, glatt, in der Farbe braun', 1, 0.7700, N'35-38', N'braun', 0)
INSERT Vertrieb.Artikel (ArtikelID, Matchcode, Artikel, Artikelbeschreibung, ArtikelgruppeID, Verkaufspreis, Groesse, Farbe, Inaktiv) VALUES (3, N'D01GR3538', N'Damensocke "Klassik" - 35-38 - grau', N'klassische Damensocke aus 100% Baumwolle, glatt, in der Farbe grau', 1, 0.7700, N'35-38', N'grau', 0)
INSERT Vertrieb.Artikel (ArtikelID, Matchcode, Artikel, Artikelbeschreibung, ArtikelgruppeID, Verkaufspreis, Groesse, Farbe, Inaktiv) VALUES (4, N'D01RO3538', N'Damensocke "Klassik" - 35-38 - rot', N'klassische Damensocke aus 100% Baumwolle, glatt, in der Farbe rot', 1, 0.7700, N'35-38', N'rot', 0)
INSERT Vertrieb.Artikel (ArtikelID, Matchcode, Artikel, Artikelbeschreibung, ArtikelgruppeID, Verkaufspreis, Groesse, Farbe, Inaktiv) VALUES (5, N'D01SC3538', N'Damensocke "Klassik" - 35-38 - schwarz', N'klassische Damensocke aus 100% Baumwolle, glatt, in der Farbe schwarz', 1, 0.7700, N'35-38', N'schwarz', 0)
INSERT Vertrieb.Artikel (ArtikelID, Matchcode, Artikel, Artikelbeschreibung, ArtikelgruppeID, Verkaufspreis, Groesse, Farbe, Inaktiv) VALUES (6, N'D01BL3942', N'Damensocke "Klassik" - 39-42 - blau', N'klassische Damensocke aus 100% Baumwolle, glatt, in der Farbe blau', 1, 0.7700, N'39-42', N'blau', 1)
INSERT Vertrieb.Artikel (ArtikelID, Matchcode, Artikel, Artikelbeschreibung, ArtikelgruppeID, Verkaufspreis, Groesse, Farbe, Inaktiv) VALUES (7, N'D01BR3942', N'Damensocke "Klassik" - 39-42 - braun', N'klassische Damensocke aus 100% Baumwolle, glatt, in der Farbe braun', 1, 0.7700, N'39-42', N'braun', 0)
INSERT Vertrieb.Artikel (ArtikelID, Matchcode, Artikel, Artikelbeschreibung, ArtikelgruppeID, Verkaufspreis, Groesse, Farbe, Inaktiv) VALUES (8, N'D01GR3942', N'Damensocke "Klassik" - 39-42 - grau', N'klassische Damensocke aus 100% Baumwolle, glatt, in der Farbe grau', 1, 0.7700, N'39-42', N'grau', 0)
INSERT Vertrieb.Artikel (ArtikelID, Matchcode, Artikel, Artikelbeschreibung, ArtikelgruppeID, Verkaufspreis, Groesse, Farbe, Inaktiv) VALUES (9, N'D01RO3942', N'Damensocke "Klassik" - 39-42 - rot', N'klassische Damensocke aus 100% Baumwolle, glatt, in der Farbe rot', 1, 0.7700, N'39-42', N'rot', 0)
INSERT Vertrieb.Artikel (ArtikelID, Matchcode, Artikel, Artikelbeschreibung, ArtikelgruppeID, Verkaufspreis, Groesse, Farbe, Inaktiv) VALUES (10, N'D01SC3942', N'Damensocke "Klassik" - 39-42 - schwarz', N'klassische Damensocke aus 100% Baumwolle, glatt, in der Farbe schwarz', 1, 0.7700, N'39-42', N'schwarz', 0)
INSERT Vertrieb.Artikel (ArtikelID, Matchcode, Artikel, Artikelbeschreibung, ArtikelgruppeID, Verkaufspreis, Groesse, Farbe, Inaktiv) VALUES (11, N'D01BL4346', N'Damensocke "Klassik" - 43-46 - blau', N'klassische Damensocke aus 100% Baumwolle, glatt, in der Farbe blau', 1, 0.7700, N'43-46', N'blau', 0)
INSERT Vertrieb.Artikel (ArtikelID, Matchcode, Artikel, Artikelbeschreibung, ArtikelgruppeID, Verkaufspreis, Groesse, Farbe, Inaktiv) VALUES (12, N'D01BR4346', N'Damensocke "Klassik" - 43-46 - braun', N'klassische Damensocke aus 100% Baumwolle, glatt, in der Farbe braun', 1, 0.7700, N'43-46', N'braun', 0)
INSERT Vertrieb.Artikel (ArtikelID, Matchcode, Artikel, Artikelbeschreibung, ArtikelgruppeID, Verkaufspreis, Groesse, Farbe, Inaktiv) VALUES (13, N'D01GR4346', N'Damensocke "Klassik" - 43-46 - grau', N'klassische Damensocke aus 100% Baumwolle, glatt, in der Farbe grau', 1, 0.7700, N'43-46', N'grau', 0)
INSERT Vertrieb.Artikel (ArtikelID, Matchcode, Artikel, Artikelbeschreibung, ArtikelgruppeID, Verkaufspreis, Groesse, Farbe, Inaktiv) VALUES (14, N'D01RO4346', N'Damensocke "Klassik" - 43-46 - rot', N'klassische Damensocke aus 100% Baumwolle, glatt, in der Farbe rot', 1, 0.7700, N'43-46', N'rot', 0)
INSERT Vertrieb.Artikel (ArtikelID, Matchcode, Artikel, Artikelbeschreibung, ArtikelgruppeID, Verkaufspreis, Groesse, Farbe, Inaktiv) VALUES (15, N'D01SC4346', N'Damensocke "Klassik" - 43-46 - schwarz', N'klassische Damensocke aus 100% Baumwolle, glatt, in der Farbe schwarz', 1, 0.7700, N'43-46', N'schwarz', 0)
INSERT Vertrieb.Artikel (ArtikelID, Matchcode, Artikel, Artikelbeschreibung, ArtikelgruppeID, Verkaufspreis, Groesse, Farbe, Inaktiv) VALUES (16, N'H01BL3538', N'Herrensocke "Klassik" - 35-38 - blau', N'klassische Herrensocke aus 100% Baumwolle, glatt, in der Farbe blau', 2, 0.7900, N'35-38', N'blau', 0)
INSERT Vertrieb.Artikel (ArtikelID, Matchcode, Artikel, Artikelbeschreibung, ArtikelgruppeID, Verkaufspreis, Groesse, Farbe, Inaktiv) VALUES (17, N'H01BR3538', N'Herrensocke "Klassik" - 35-38 - braun', N'klassische Herrensocke aus 100% Baumwolle, glatt, in der Farbe braun', 2, 0.7900, N'35-38', N'braun', 0)
INSERT Vertrieb.Artikel (ArtikelID, Matchcode, Artikel, Artikelbeschreibung, ArtikelgruppeID, Verkaufspreis, Groesse, Farbe, Inaktiv) VALUES (18, N'H01GR3538', N'Herrensocke "Klassik" - 35-38 - grau', N'klassische Herrensocke aus 100% Baumwolle, glatt, in der Farbe grau', 2, 0.7900, N'35-38', N'grau', 0)
INSERT Vertrieb.Artikel (ArtikelID, Matchcode, Artikel, Artikelbeschreibung, ArtikelgruppeID, Verkaufspreis, Groesse, Farbe, Inaktiv) VALUES (19, N'H01RO3538', N'Herrensocke "Klassik" - 35-38 - rot', N'klassische Herrensocke aus 100% Baumwolle, glatt, in der Farbe rot', 2, 0.7900, N'35-38', N'rot', 0)
INSERT Vertrieb.Artikel (ArtikelID, Matchcode, Artikel, Artikelbeschreibung, ArtikelgruppeID, Verkaufspreis, Groesse, Farbe, Inaktiv) VALUES (20, N'H01SC3538', N'Herrensocke "Klassik" - 35-38 - schwarz', N'klassische Herrensocke aus 100% Baumwolle, glatt, in der Farbe schwarz', 2, 0.7900, N'35-38', N'schwarz', 0)
INSERT Vertrieb.Artikel (ArtikelID, Matchcode, Artikel, Artikelbeschreibung, ArtikelgruppeID, Verkaufspreis, Groesse, Farbe, Inaktiv) VALUES (21, N'H01BL3942', N'Herrensocke "Klassik" - 39-42 - blau', N'klassische Herrensocke aus 100% Baumwolle, glatt, in der Farbe blau', 2, 0.7900, N'39-42', N'blau', 0)
INSERT Vertrieb.Artikel (ArtikelID, Matchcode, Artikel, Artikelbeschreibung, ArtikelgruppeID, Verkaufspreis, Groesse, Farbe, Inaktiv) VALUES (22, N'H01BR3942', N'Herrensocke "Klassik" - 39-42 - braun', N'klassische Herrensocke aus 100% Baumwolle, glatt, in der Farbe braun', 2, 0.7900, N'39-42', N'braun', 0)
INSERT Vertrieb.Artikel (ArtikelID, Matchcode, Artikel, Artikelbeschreibung, ArtikelgruppeID, Verkaufspreis, Groesse, Farbe, Inaktiv) VALUES (23, N'H01GR3942', N'Herrensocke "Klassik" - 39-42 - grau', N'klassische Herrensocke aus 100% Baumwolle, glatt, in der Farbe grau', 2, 0.7900, N'39-42', N'grau', 0)
INSERT Vertrieb.Artikel (ArtikelID, Matchcode, Artikel, Artikelbeschreibung, ArtikelgruppeID, Verkaufspreis, Groesse, Farbe, Inaktiv) VALUES (24, N'H01RO3942', N'Herrensocke "Klassik" - 39-42 - rot', N'klassische Herrensocke aus 100% Baumwolle, glatt, in der Farbe rot', 2, 0.7900, N'39-42', N'rot', 0)
INSERT Vertrieb.Artikel (ArtikelID, Matchcode, Artikel, Artikelbeschreibung, ArtikelgruppeID, Verkaufspreis, Groesse, Farbe, Inaktiv) VALUES (25, N'H01SC3942', N'Herrensocke "Klassik" - 39-42 - schwarz', N'klassische Herrensocke aus 100% Baumwolle, glatt, in der Farbe schwarz', 2, 0.7900, N'39-42', N'schwarz', 0)
INSERT Vertrieb.Artikel (ArtikelID, Matchcode, Artikel, Artikelbeschreibung, ArtikelgruppeID, Verkaufspreis, Groesse, Farbe, Inaktiv) VALUES (26, N'H01BL4346', N'Herrensocke "Klassik" - 43-46 - blau', N'klassische Herrensocke aus 100% Baumwolle, glatt, in der Farbe blau', 2, 0.7900, N'43-46', N'blau', 0)
INSERT Vertrieb.Artikel (ArtikelID, Matchcode, Artikel, Artikelbeschreibung, ArtikelgruppeID, Verkaufspreis, Groesse, Farbe, Inaktiv) VALUES (27, N'H01BR4346', N'Herrensocke "Klassik" - 43-46 - braun', N'klassische Herrensocke aus 100% Baumwolle, glatt, in der Farbe braun', 2, 0.7900, N'43-46', N'braun', 0)
INSERT Vertrieb.Artikel (ArtikelID, Matchcode, Artikel, Artikelbeschreibung, ArtikelgruppeID, Verkaufspreis, Groesse, Farbe, Inaktiv) VALUES (28, N'H01GR4346', N'Herrensocke "Klassik" - 43-46 - grau', N'klassische Herrensocke aus 100% Baumwolle, glatt, in der Farbe grau', 2, 0.7900, N'43-46', N'grau', 0)
INSERT Vertrieb.Artikel (ArtikelID, Matchcode, Artikel, Artikelbeschreibung, ArtikelgruppeID, Verkaufspreis, Groesse, Farbe, Inaktiv) VALUES (29, N'H01RO4346', N'Herrensocke "Klassik" - 43-46 - rot', N'klassische Herrensocke aus 100% Baumwolle, glatt, in der Farbe rot', 2, 0.7900, N'43-46', N'rot', 0)
INSERT Vertrieb.Artikel (ArtikelID, Matchcode, Artikel, Artikelbeschreibung, ArtikelgruppeID, Verkaufspreis, Groesse, Farbe, Inaktiv) VALUES (30, N'H01SC4346', N'Herrensocke "Klassik" - 43-46 - schwarz', N'klassische Herrensocke aus 100% Baumwolle, glatt, in der Farbe schwarz', 2, 0.7900, N'43-46', N'schwarz', 0)
INSERT Vertrieb.Artikel (ArtikelID, Matchcode, Artikel, Artikelbeschreibung, ArtikelgruppeID, Verkaufspreis, Groesse, Farbe, Inaktiv) VALUES (31, N'D01G3538 ', N'Damensocke "Klassik" - 35-38 - grn', N'klassische Damensocke aus 100% Baumwolle, glatt, in der Farbe grn', 1, 0.7700, N'35-38', N'grn', 0)
INSERT Vertrieb.Artikel (ArtikelID, Matchcode, Artikel, Artikelbeschreibung, ArtikelgruppeID, Verkaufspreis, Groesse, Farbe, Inaktiv) VALUES (32, N'D01G3942 ', N'Damensocke "Klassik" - 39-42 - grn', N'klassische Damensocke aus 100% Baumwolle, glatt, in der Farbe grn', 1, 0.7700, N'39-42', N'grn', 0)
INSERT Vertrieb.Artikel (ArtikelID, Matchcode, Artikel, Artikelbeschreibung, ArtikelgruppeID, Verkaufspreis, Groesse, Farbe, Inaktiv) VALUES (33, N'D01G4346 ', N'Damensocke "Klassik" - 43-46 - grn', N'klassische Damensocke aus 100% Baumwolle, glatt, in der Farbe grn', 1, 0.7700, N'43-46', N'grn', 0)
INSERT Vertrieb.Artikel (ArtikelID, Matchcode, Artikel, Artikelbeschreibung, ArtikelgruppeID, Verkaufspreis, Groesse, Farbe, Inaktiv) VALUES (34, N'H01G3538 ', N'Herrensocke "Klassik" - 35-38 - grn', N'klassische Herrensocke aus 100% Baumwolle, glatt, in der Farbe grn', 2, 0.7900, N'35-38', N'grn', 0)
INSERT Vertrieb.Artikel (ArtikelID, Matchcode, Artikel, Artikelbeschreibung, ArtikelgruppeID, Verkaufspreis, Groesse, Farbe, Inaktiv) VALUES (35, N'H01G3942 ', N'Herrensocke "Klassik" - 39-42 - grn', N'klassische Herrensocke aus 100% Baumwolle, glatt, in der Farbe grn', 2, 0.7900, N'39-42', N'grn', 0)
INSERT Vertrieb.Artikel (ArtikelID, Matchcode, Artikel, Artikelbeschreibung, ArtikelgruppeID, Verkaufspreis, Groesse, Farbe, Inaktiv) VALUES (36, N'H01G4346 ', N'Herrensocke "Klassik" - 43-46 - grn', N'klassische Herrensocke aus 100% Baumwolle, glatt, in der Farbe grn', 2, 0.7900, N'43-46', N'grn', 0)
SET IDENTITY_INSERT Vertrieb.Artikel OFF

SET IDENTITY_INSERT Vertrieb.Auftraege ON
INSERT Vertrieb.Auftraege (AuftragID, KundenID, MitarbeiterID, Auftragsdatum) VALUES (1, 9, 9, '20180312 10:00:00.000')
INSERT Vertrieb.Auftraege (AuftragID, KundenID, MitarbeiterID, Auftragsdatum) VALUES (2, 1, 6, '20180312 11:00:00.000')
INSERT Vertrieb.Auftraege (AuftragID, KundenID, MitarbeiterID, Auftragsdatum) VALUES (3, 3, 3, '20180312 12:00:00.000')
INSERT Vertrieb.Auftraege (AuftragID, KundenID, MitarbeiterID, Auftragsdatum) VALUES (4, 1, 6, '20180326 13:00:00.000')
INSERT Vertrieb.Auftraege (AuftragID, KundenID, MitarbeiterID, Auftragsdatum) VALUES (5, 1, 6, '20180326 14:00:00.000')
INSERT Vertrieb.Auftraege (AuftragID, KundenID, MitarbeiterID, Auftragsdatum) VALUES (6, 3, 3, '20180326 15:00:00.000')
INSERT Vertrieb.Auftraege (AuftragID, KundenID, MitarbeiterID, Auftragsdatum) VALUES (7, 8, 4, '20180326 16:00:00.000')
INSERT Vertrieb.Auftraege (AuftragID, KundenID, MitarbeiterID, Auftragsdatum) VALUES (8, 7, 2, '20180429 17:00:00.000')
INSERT Vertrieb.Auftraege (AuftragID, KundenID, MitarbeiterID, Auftragsdatum) VALUES (9, 1, 6, '20180429 10:00:00.000')
INSERT Vertrieb.Auftraege (AuftragID, KundenID, MitarbeiterID, Auftragsdatum) VALUES (10, 2, 7, '20180429 09:00:00.000')
INSERT Vertrieb.Auftraege (AuftragID, KundenID, MitarbeiterID, Auftragsdatum) VALUES (11, 10, 4, '20180429 11:00:00.000')
INSERT Vertrieb.Auftraege (AuftragID, KundenID, MitarbeiterID, Auftragsdatum) VALUES (12, 8, 4, '20180429 12:00:00.000')
INSERT Vertrieb.Auftraege (AuftragID, KundenID, MitarbeiterID, Auftragsdatum) VALUES (13, 6, 9, '20180429 13:00:00.000')
INSERT Vertrieb.Auftraege (AuftragID, KundenID, MitarbeiterID, Auftragsdatum) VALUES (14, 1, 6, '20180429 15:00:00.000')
INSERT Vertrieb.Auftraege (AuftragID, KundenID, MitarbeiterID, Auftragsdatum) VALUES (15, 1, 6, '20180430 16:00:00.000')
INSERT Vertrieb.Auftraege (AuftragID, KundenID, MitarbeiterID, Auftragsdatum) VALUES (16, 1, 6, '20180430 09:00:00.000')
INSERT Vertrieb.Auftraege (AuftragID, KundenID, MitarbeiterID, Auftragsdatum) VALUES (17, 1, 6, '20180430 11:00:00.000')
SET IDENTITY_INSERT Vertrieb.Auftraege OFF

SET IDENTITY_INSERT Vertrieb.Auftragspositionen ON 
INSERT Vertrieb.Auftragspositionen (AuftragspositionID, AuftragID, ArtikelID, Position, Einzelpreis, Menge) VALUES (7686, 17, 14, 1, 0.7700, 5)
INSERT Vertrieb.Auftragspositionen (AuftragspositionID, AuftragID, ArtikelID, Position, Einzelpreis, Menge) VALUES (7688, 16, 1, 1, 0.7700, 7)
INSERT Vertrieb.Auftragspositionen (AuftragspositionID, AuftragID, ArtikelID, Position, Einzelpreis, Menge) VALUES (7689, 16, 11, 2, 0.7700, 3)
INSERT Vertrieb.Auftragspositionen (AuftragspositionID, AuftragID, ArtikelID, Position, Einzelpreis, Menge) VALUES (7690, 16, 27, 3, 0.7900, 5)
INSERT Vertrieb.Auftragspositionen (AuftragspositionID, AuftragID, ArtikelID, Position, Einzelpreis, Menge) VALUES (7691, 15, 20, 1, 0.7900, 2)
INSERT Vertrieb.Auftragspositionen (AuftragspositionID, AuftragID, ArtikelID, Position, Einzelpreis, Menge) VALUES (7692, 15, 25, 2, 0.7900, 7)
INSERT Vertrieb.Auftragspositionen (AuftragspositionID, AuftragID, ArtikelID, Position, Einzelpreis, Menge) VALUES (7693, 14, 9, 1, 0.7700, 9)
INSERT Vertrieb.Auftragspositionen (AuftragspositionID, AuftragID, ArtikelID, Position, Einzelpreis, Menge) VALUES (7694, 13, 10, 1, 0.7700, 8)
INSERT Vertrieb.Auftragspositionen (AuftragspositionID, AuftragID, ArtikelID, Position, Einzelpreis, Menge) VALUES (7695, 13, 16, 2, 0.7900, 6)
INSERT Vertrieb.Auftragspositionen (AuftragspositionID, AuftragID, ArtikelID, Position, Einzelpreis, Menge) VALUES (7696, 12, 7, 1, 0.7700, 8)
INSERT Vertrieb.Auftragspositionen (AuftragspositionID, AuftragID, ArtikelID, Position, Einzelpreis, Menge) VALUES (7697, 11, 14, 1, 0.7700, 3)
INSERT Vertrieb.Auftragspositionen (AuftragspositionID, AuftragID, ArtikelID, Position, Einzelpreis, Menge) VALUES (7698, 10, 15, 1, 0.7700, 1)
INSERT Vertrieb.Auftragspositionen (AuftragspositionID, AuftragID, ArtikelID, Position, Einzelpreis, Menge) VALUES (7699, 10, 26, 2, 0.7900, 2)
INSERT Vertrieb.Auftragspositionen (AuftragspositionID, AuftragID, ArtikelID, Position, Einzelpreis, Menge) VALUES (7700, 9, 28, 1, 0.7900, 5)
INSERT Vertrieb.Auftragspositionen (AuftragspositionID, AuftragID, ArtikelID, Position, Einzelpreis, Menge) VALUES (7701, 8, 17, 1, 0.7900, 5)
INSERT Vertrieb.Auftragspositionen (AuftragspositionID, AuftragID, ArtikelID, Position, Einzelpreis, Menge) VALUES (7702, 7, 2, 1, 0.7700, 1)
INSERT Vertrieb.Auftragspositionen (AuftragspositionID, AuftragID, ArtikelID, Position, Einzelpreis, Menge) VALUES (7703, 7, 16, 2, 0.7900, 7)
INSERT Vertrieb.Auftragspositionen (AuftragspositionID, AuftragID, ArtikelID, Position, Einzelpreis, Menge) VALUES (7704, 7, 20, 3, 0.7900, 8)
INSERT Vertrieb.Auftragspositionen (AuftragspositionID, AuftragID, ArtikelID, Position, Einzelpreis, Menge) VALUES (7706, 6, 25, 1, 0.7900, 4)
INSERT Vertrieb.Auftragspositionen (AuftragspositionID, AuftragID, ArtikelID, Position, Einzelpreis, Menge) VALUES (7707, 6, 27, 2, 0.7900, 4)
INSERT Vertrieb.Auftragspositionen (AuftragspositionID, AuftragID, ArtikelID, Position, Einzelpreis, Menge) VALUES (7711, 5, 2, 1, 0.7700, 6)
INSERT Vertrieb.Auftragspositionen (AuftragspositionID, AuftragID, ArtikelID, Position, Einzelpreis, Menge) VALUES (7712, 5, 23, 2, 0.7900, 9)
INSERT Vertrieb.Auftragspositionen (AuftragspositionID, AuftragID, ArtikelID, Position, Einzelpreis, Menge) VALUES (7713, 4, 2, 1, 0.7700, 7)
INSERT Vertrieb.Auftragspositionen (AuftragspositionID, AuftragID, ArtikelID, Position, Einzelpreis, Menge) VALUES (7714, 4, 24, 2, 0.7900, 7)
INSERT Vertrieb.Auftragspositionen (AuftragspositionID, AuftragID, ArtikelID, Position, Einzelpreis, Menge) VALUES (7715, 4, 25, 3, 0.7900, 3)
INSERT Vertrieb.Auftragspositionen (AuftragspositionID, AuftragID, ArtikelID, Position, Einzelpreis, Menge) VALUES (7716, 4, 27, 4, 0.7900, 3)
INSERT Vertrieb.Auftragspositionen (AuftragspositionID, AuftragID, ArtikelID, Position, Einzelpreis, Menge) VALUES (7720, 3, 16, 1, 0.7900, 4)
INSERT Vertrieb.Auftragspositionen (AuftragspositionID, AuftragID, ArtikelID, Position, Einzelpreis, Menge) VALUES (7725, 2, 6, 1, 0.7700, 2)
INSERT Vertrieb.Auftragspositionen (AuftragspositionID, AuftragID, ArtikelID, Position, Einzelpreis, Menge) VALUES (7726, 1, 6, 1, 0.7700, 5)
SET IDENTITY_INSERT Vertrieb.Auftragspositionen OFF
GO

SET NOCOUNT OFF;

PRINT 'Fertig!';
GO